// Copyright 2015 Google Inc.

#import <Foundation/NSObject.h>

#import <GoogleCastRemoteDisplay/GCKRemoteDisplayDefines.h>

@protocol GCKRemoteDisplaySession;

GCK_ASSUME_NONNULL_BEGIN

/**
 * Base class for video frame inputs.
 *
 * Video frame inputs are adaptors that facilitate the submission of video frames to a Remote
 * Display session. They are bound to a specific session and cannot be reused or shared.
 *
 * @sa GCKMetalVideoFrameInput
 * @sa GCKOpenGLESVideoFrameInput
 * @sa GCKViewVideoFrameInput
 * @ingroup RemoteDisplay
 */
GCK_EXPORT
@interface GCKVideoFrameInput : NSObject

/** Remote Display session the input is bound to. */
@property(nonatomic, weak, readonly, GCK_NULLABLE) id<GCKRemoteDisplaySession> session;

/** Width of the session's video stream. */
@property(nonatomic, readonly) uint32_t width;

/** Height of the session's video stream. */
@property(nonatomic, readonly) uint32_t height;

/** Initialize a new video frame input bound to the specified session. */
- (instancetype)initWithSession:(id<GCKRemoteDisplaySession>)session NS_DESIGNATED_INITIALIZER;

- (instancetype)init NS_UNAVAILABLE;
@end

GCK_ASSUME_NONNULL_END
